@@ -345,6 +345,8 @@ class CreateRecTaskRequest(AbstractModel):
 • 16k_en：16k 英语；
 • 16k_ca：16k 粤语；
 • 16k_ja：16k 日语；
+• 16k_vi：16k 越南语；
+• 16k_ms：16k 马来语；
 • 16k_zh_edu 中文教育；
 • 16k_en_edu 英文教育；
 • 16k_zh_medical  医疗；
@@ -1209,6 +1211,8 @@ class SentenceRecognitionRequest(AbstractModel):
 • 16k_en：16k 英语；
 • 16k_ca：16k 粤语；
 • 16k_ja：16k 日语；
+• 16k_vi：16k 越南语；
+• 16k_ms：16k 马来语；
 • 16k_zh_medical：16k 医疗；
 • 16k_zh-PY 中英粤;
 • 16k_zh_dialect：多方言，支持23种方言（上海话、四川话、武汉话、贵阳话、昆明话、西安话、郑州话、太原话、兰州话、银川话、西宁话、南京话、合肥话、南昌话、长沙话、苏州话、杭州话、济南话、天津话、石家庄话、黑龙江话、吉林话、辽宁话）；
